@@ -144,9 +144,9 @@ class ExecutableParser(object):
         them to the specified parent."""
         for anexec in self.RE_EXEC.finditer(contents):
             x = self._process_execs(anexec, parent, module)
-            parent.executables[x.name] = x
+            parent.executables[x.name.lower()] = x
             if  isinstance(parent, Module) and "public" in x.modifiers:
-                parent.publics[x.name] = 1
+                parent.publics[x.name.lower()] = 1
             
             #To handle the embedded executables, run this method recursively
             self.parse_block(x.contents, x, module, depth + 1)
@@ -400,7 +400,6 @@ class ExecutableParser(object):
         #First get the variables declared in the body of the executable, these can
         #be either locals or parameter declarations.
         members = self.vparser.parse(contents, anexec)
-        
         #If the name matches one in the parameter list, we can connect them
         for param in list(params):
             lparam = param.lower()
